@@ -15,6 +15,7 @@ License along with this library; see the file COPYING.LIB.  If
 not, write to the Free Software Foundation, Inc., 675 Mass Ave,
 Cambridge, MA 02139, USA.  */
 
+#include <features.h>
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
@@ -24,6 +25,7 @@ Cambridge, MA 02139, USA.  */
 #include <dirent.h>
 #include <malloc.h>
 #include <fnmatch.h>
+#define _GNU_SOURCE
 #include <glob.h>
 
 extern __ptr_t (*__glob_opendir_hook) __P ((const char *directory));
@@ -31,7 +33,6 @@ extern void (*__glob_closedir_hook) __P ((__ptr_t stream));
 extern const char *(*__glob_readdir_hook) __P ((__ptr_t stream));
 
 
-static int glob_pattern_p __P ((const char *pattern, int quote));
 static int glob_in_dir __P ((const char *pattern, const char *directory,
 			     int flags,
 			     int (*errfunc) __P ((const char *, int)),
@@ -40,6 +41,43 @@ static int prefix_array __P ((const char *prefix, char **array, size_t n,
 			      int add_slash));
 static int collated_compare __P ((const __ptr_t, const __ptr_t));
 
+#ifdef __GLOB64
+extern int glob_pattern_p(const char *pattern, int quote);
+#else
+/* Return nonzero if PATTERN contains any metacharacters.
+   Metacharacters can be quoted with backslashes if QUOTE is nonzero.  */
+int glob_pattern_p(const char *pattern, int quote)
+{
+    const char *p;
+    int open = 0;
+
+    for (p = pattern; *p != '\0'; ++p)
+	switch (*p)
+	{
+	    case '?':
+	    case '*':
+		return 1;
+
+	    case '\\':
+		if (quote)
+		    ++p;
+		break;
+
+	    case '[':
+		open = 1;
+		break;
+
+	    case ']':
+		if (open)
+		    return 1;
+		break;
+	}
+
+    return 0;
+}
+#endif
+
+
 /* Do glob searching for PATTERN, placing results in PGLOB.
    The bits defined above may be set in FLAGS.
    If a directory cannot be opened or read and ERRFUNC is not nil,
@@ -331,42 +369,6 @@ prefix_array (dirname, array, n, add_slash)
 }
 
 
-/* Return nonzero if PATTERN contains any metacharacters.
-   Metacharacters can be quoted with backslashes if QUOTE is nonzero.  */
-static int
-glob_pattern_p (pattern, quote)
-     const char *pattern;
-     int quote;
-{
-  register const char *p;
-  int open = 0;
-
-  for (p = pattern; *p != '\0'; ++p)
-    switch (*p)
-      {
-      case '?':
-      case '*':
-	return 1;
-
-      case '\\':
-	if (quote)
-	  ++p;
-	break;
-
-      case '[':
-	open = 1;
-	break;
-
-      case ']':
-	if (open)
-	  return 1;
-	break;
-      }
-
-  return 0;
-}
-
-
 /* Like `glob', but PATTERN is a final pathname component,
    and matches are searched for in DIRECTORY.
    The GLOB_NOSORT bit in FLAGS is ignored.  No sorting is ever done.
